

/* 
   orxonox - the future of 3D-vertical-scrollers

   Copyright (C) 2004 orx

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   ### File Specific:
   main-programmer: Patrick Boenzli
   co-programmer:
*/


#include "world.h"

#include <iostream>

using namespace std;


/** 
   \brief Create a new World
   
   This creates a new empty world!
*/
World::World () {
  lastPlayer = null;
  lastNPC = null;
}


World::~World () {}


/** 
   \brief Add Player
   \param player A reference to the new player object
   
   Add a new Player to the game. Player has to be initialised previously 
*/
bool World::addPlayer(Player* player) 
{
  playerList* listMember = new playerList;
  listMember->player = player;
  if ( lastPlayer != null ) 
    {
      listMember->number = lastPlayer->number + 1;
      listMember->next = lastPlayer;
    }
  else 
    {
      listMember->number = 0;
      listMember->next = null;
    }
  lastPlayer = listMember;
}


/** 
   \brief Remove Player
   \param player A reference to the new npc object
   
   Remove a new Player to the game.
*/
bool World::removePlayer(Player* player) {
  cout << "World::removeNPC not implemented yet" << endl;
}


/** 
   \brief Add Non-Player-Character
   \param player A reference to the new npc object
   
   Add a new Non-Player-Character to the game. Player has to be initialised previously 
*/
bool World::addNPC(NPC* npc) 
{
  npcList* listMember = new npcList;
  listMember->npc = npc;
  if ( lastNPC != null ) 
    {
      listMember->number = lastNPC->number + 1;
      listMember->next = lastNPC;
    }
  else 
    {
      listMember->number = 0;
      listMember->next = null;
    }
  lastNPC = listMember;
}


/** 
   \brief Remove Non-Player-Character
   \param player A reference to the new npc object
   
   Remove a new Non-Player-Character to the game.
*/
bool World::removeNPC(NPC* npc) {
  cout << "World::removeNPC not implemented yet" << endl;
}



/** 
   \brief Draws the World and all Objects contained
   
   Calls the draw function of all: Objects, Players, Environement
*/
void World::drawWorld(void) 
{
  playerList* tmpPlayer = lastPlayer;
  Player* player = tmpPlayer->player;
  while( tmpPlayer != null ) 
    {
      (*tmpPlayer->player).drawPlayer();
      tmpPlayer = tmpPlayer->next;
    }
  npcList* tmpNPC = lastNPC;
  while( tmpNPC != null )
    {
      (*tmpNPC->npc).drawNPC();
      tmpNPC = tmpNPC->next;
    }
}


/** 
   \brief Updates the world and all its objects
   
   Calculates the new state of the world. User-input and AI of
   the enemies are accounted for.
*/
void World::updateWorld(void) 
{
  

}



/** 
   \brief Routine for testing purposes.
   
   testing, testing, testing...
*/
void World::testThaTest(void) 
{
  cout << "World::testThaTest() called" << endl;
  /* test addPlayer */
  cout << "addPlayer test..." << endl;
  playerList* pl = lastPlayer;
  while ( pl != null )
    {
      cout << "player " << pl->number << " was found" << endl;
      pl = pl->next;
    }

  /* test addNPC */
  cout << "addNPC test..." << endl;
  npcList* nl = lastNPC;
  while ( nl != null )
    {
      cout << "npc " << nl->number << " was found" << endl;
      nl = nl->next;
    }

  /* test drawWorld() */
  cout << "drawWorld()..." << endl;
  drawWorld();

  cout << "World::testThaTest() finished" << endl;
}
